@@ -2,10 +2,10 @@ package Mew;
 
 use strictures 2;
 
-our $VERSION = '1.001003'; # VERSION
+our $VERSION = '1.001004'; # VERSION
 
 use Import::Into;
-use base 'Moo';
+use Moo;
 
 sub import {
     my $class = shift;
